@@ -29,20 +29,21 @@
 #include "units.h"
 #include "commondef.h"
 
-#include <DHiDPIHelper>
+
 #include <DPalette>
 #include <DFontSizeManager>
 #include <DWidgetUtil>
 #include <DTitlebar>
-#include <DApplicationHelper>
 #include <DSettings>
 #include <DSettingsGroup>
 #include <DSettingsOption>
 #include <DSettingsWidgetFactory>
 #include <DBackgroundGroup>
 #include <DMessageManager>
-
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #include <QDesktopWidget>
+#endif
+
 #include <QJsonDocument>
 #include <QJsonParseError>
 #include <QJsonObject>
@@ -50,6 +51,7 @@
 #include <QSizePolicy>
 #include <QHBoxLayout>
 #include <QWidget>
+#include <QScreen>
 #include <QMenuBar>
 #include <QMouseEvent>
 #include <QColorDialog>
@@ -98,14 +100,15 @@ Calendarmainwindow::Calendarmainwindow(int index, QWidget *w)
     connect(viewshortcut, SIGNAL(activated()), this, SLOT(slotViewShortcut()));
 
     setTitlebarShadowEnabled(true);
-    //获取桌面窗口大小
-    QDesktopWidget *desktopwidget = QApplication::desktop();
     //若分辨率改变则重新设置最大尺寸
-    connect(desktopwidget, &QDesktopWidget::resized, this, &Calendarmainwindow::slotSetMaxSize);
-    slotSetMaxSize();
+    const auto screens = QGuiApplication::screens();
+    for (QScreen *screen : screens) {
+        connect(screen, &QScreen::geometryChanged, this, &Calendarmainwindow::slotSetMaxSize);
+    }
 
     //兼容以前的配置信息
     if (CConfigSettings::getInstance()->contains("base.geometry")) {
+        qCDebug(ClientLogger) << "Restoring window geometry from legacy config";
         QByteArray arrayByte = CConfigSettings::getInstance()->value("base.geometry").toByteArray();
         bool isOk = false;
         int state = CConfigSettings::getInstance()->value("base.state").toInt(&isOk);
@@ -120,12 +123,14 @@ Calendarmainwindow::Calendarmainwindow(int index, QWidget *w)
         CConfigSettings::getInstance()->remove("base.geometry");
         CConfigSettings::getInstance()->remove("base.state");
     } else if (CConfigSettings::getInstance()->contains("base.windowWidth")) {
+        qCDebug(ClientLogger) << "Restoring window size from config";
         //获取窗口的宽度和高度
         int width = CConfigSettings::getInstance()->value("base.windowWidth").toInt();
         int height = CConfigSettings::getInstance()->value("base.windowHeight").toInt();
         QRect rect(0, 0, width, height);
         this->setGeometry(rect);
     } else {
+        qCDebug(ClientLogger) << "Using default window size";
         //如果没有相关配置则设置为默认尺寸
         QRect rect(0, 0, Calendar_Default_Width, Calendar_Default_Height);
         this->setGeometry(rect);
@@ -171,6 +176,7 @@ void Calendarmainwindow::slotCurrentDateUpdate()
     m_DayWindow->setCurrentDateTime(_currentDate);
     //如果当前日期与动态图标日期不一样则重新生成动态图标
     if (_currentDate.date() != CDynamicIcon::getInstance()->getDate()) {
+        qCDebug(ClientLogger) << "Updating dynamic icon date" << "new date:" << QDate::currentDate();
         CDynamicIcon::getInstance()->setDate(QDate::currentDate());
         CDynamicIcon::getInstance()->setIcon();
         //更新视图数据显示
@@ -201,8 +207,9 @@ void Calendarmainwindow::slotSetSearchFocus()
  */
 void Calendarmainwindow::viewWindow(int type, const bool showAnimation)
 {
+    qCDebug(ClientLogger) << "Switching view window" << "type:" << type << "show animation:" << showAnimation;
     if (type < 0 || type >= m_stackWidget->count()) {
-        qCWarning(ClientLogger) << "set view error,set index:" << type;
+        qCWarning(ClientLogger) << "Invalid view type:" << type;
         return;
     }
     if (showAnimation) {
@@ -216,14 +223,17 @@ void Calendarmainwindow::viewWindow(int type, const bool showAnimation)
     }
     switch (type) {
     case DDECalendar::CalendarYearWindow: {
-        //更新界面显示
+        qCDebug(ClientLogger) << "Updating year window display";
         m_yearwindow->updateData();
     } break;
     case DDECalendar::CalendarMonthWindow: {
+        qCDebug(ClientLogger) << "Switching to month window";
     } break;
     case DDECalendar::CalendarWeekWindow: {
+        qCDebug(ClientLogger) << "Switching to week window";
     } break;
     case DDECalendar::CalendarDayWindow: {
+        qCDebug(ClientLogger) << "Switching to day window";
         m_DayWindow->setTime();
         m_searchflag = true;
     } break;
@@ -263,34 +273,37 @@ void Calendarmainwindow::setSearchWidth(int w)
 
 void Calendarmainwindow::slotTheme(int type)
 {
+    qCDebug(ClientLogger) << "Setting application theme" << "type:" << type;
     if (type == 0) {
         type = DGuiApplicationHelper::instance()->themeType();
     }
 
     if (type == 1) {
+        qCDebug(ClientLogger) << "Applying light theme";
         DPalette anipa = m_contentBackground->palette();
-        anipa.setColor(DPalette::Background, "#F8F8F8");
+        anipa.setColor(DPalette::Window, "#F8F8F8");
         m_contentBackground->setPalette(anipa);
-        m_contentBackground->setBackgroundRole(DPalette::Background);
+        m_contentBackground->setBackgroundRole(DPalette::Window);
 
         DPalette tframepa = m_transparentFrame->palette();
         QColor tColor = "#FFFFFF";
         tColor.setAlphaF(0.3);
-        tframepa.setColor(DPalette::Background, tColor);
+        tframepa.setColor(DPalette::Window, tColor);
         m_transparentFrame->setPalette(tframepa);
-        m_transparentFrame->setBackgroundRole(DPalette::Background);
+        m_transparentFrame->setBackgroundRole(DPalette::Window);
     } else {
+        qCDebug(ClientLogger) << "Applying dark theme";
         DPalette anipa = m_contentBackground->palette();
-        anipa.setColor(DPalette::Background, "#252525");
+        anipa.setColor(DPalette::Window, "#252525");
         m_contentBackground->setPalette(anipa);
-        m_contentBackground->setBackgroundRole(DPalette::Background);
+        m_contentBackground->setBackgroundRole(DPalette::Window);
 
         DPalette tframepa = m_transparentFrame->palette();
         QColor tColor = "#000000";
         tColor.setAlphaF(0.3);
-        tframepa.setColor(DPalette::Background, tColor);
+        tframepa.setColor(DPalette::Window, tColor);
         m_transparentFrame->setPalette(tframepa);
-        m_transparentFrame->setBackgroundRole(DPalette::Background);
+        m_transparentFrame->setBackgroundRole(DPalette::Window);
     }
     CScheduleDataManage::getScheduleDataManage()->setTheMe(type);
     m_yearwindow->setTheMe(type);
@@ -302,8 +315,11 @@ void Calendarmainwindow::slotTheme(int type)
 
 void Calendarmainwindow::slotOpenSchedule(QString job)
 {
-    if (job.isEmpty())
+    if (job.isEmpty()) {
+        qCWarning(ClientLogger) << "Attempted to open empty schedule";
         return;
+    }
+    qCDebug(ClientLogger) << "Opening schedule" << "job:" << job;
     DSchedule::Ptr out;
     DSchedule::fromJsonString(out, job);
 
@@ -398,7 +414,7 @@ void Calendarmainwindow::initUI()
     m_contentBackground->setObjectName("ScheduleSearchWidgetBackgroundFrame");
     m_contentBackground->setContentsMargins(0, 0, 0, 0);
     DPalette anipa = m_contentBackground->palette();
-    anipa.setColor(DPalette::Background, "#F8F8F8");
+    anipa.setColor(DPalette::Window, "#F8F8F8");
     m_contentBackground->setAutoFillBackground(true);
     m_contentBackground->setPalette(anipa);
 
@@ -408,7 +424,7 @@ void Calendarmainwindow::initUI()
     m_scheduleSearchView->setAccessibleDescription("Window showing search results");
 
     QVBoxLayout *ssLayout = new QVBoxLayout;
-    ssLayout->setMargin(0);
+    ssLayout->setContentsMargins(0, 0, 0, 0);
     ssLayout->setSpacing(0);
     ssLayout->addWidget(m_scheduleSearchView, 1);
     m_contentBackground->setLayout(ssLayout);
@@ -774,6 +790,7 @@ void Calendarmainwindow::slotNewSchedule()
 
 void Calendarmainwindow::slotDeleteitem()
 {
+    qCDebug(ClientLogger) << "Deleting selected item";
     if (m_scheduleSearchView->getHasScheduleShow() && m_scheduleSearchView->getScheduleStatus()) {
         //删除选中的schedule
         m_scheduleSearchView->deleteSchedule();
@@ -790,11 +807,15 @@ void Calendarmainwindow::slotDeleteitem()
  * @brief Calendarmainwindow::slotSetMaxSize    根据屏幕分辨率调整窗口最大尺寸
  * @param size
  */
-void Calendarmainwindow::slotSetMaxSize(int size)
+void Calendarmainwindow::slotSetMaxSize()
 {
-    Q_UNUSED(size);
+    qCDebug(ClientLogger) << "Setting maximum window size based on screen resolution";
     //获取屏幕大小
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    QSize deskSize = QGuiApplication::primaryScreen()->size();
+#else
     QSize deskSize = QApplication::desktop()->size();
+#endif
     //设置最大尺寸为屏幕尺寸
     setMaximumSize(deskSize);
     if (TabletConfig::isTablet()) {
@@ -931,6 +952,7 @@ void Calendarmainwindow::removeSyncToast()
 
 void Calendarmainwindow::slotShowSyncToast(int syncNum)
 {
+    qCDebug(ClientLogger) << "Showing sync toast" << "sync number:" << syncNum;
     //-1:正在刷新 0:正常 1:网络异常 2:服务器异常 3：存储已经满
     static int preSyncNum = -2;
     if (preSyncNum != syncNum && syncNum == -1) {
@@ -945,6 +967,7 @@ void Calendarmainwindow::slotShowSyncToast(int syncNum)
         preSyncNum = -2;
         switch (syncNum) {
         case 0: {
+            qCDebug(ClientLogger) << "Sync completed successfully";
             //同步成功
             removeSyncToast();
             DMessageManager::instance()->sendMessage(this->window(), QIcon::fromTheme(":/icons/deepin/builtin/icons/dde_calendar_success_200px.png"), tr("Sync successful"));
@@ -953,6 +976,7 @@ void Calendarmainwindow::slotShowSyncToast(int syncNum)
         case 1:
         case 2:
         case 3: {
+            qCWarning(ClientLogger) << "Sync failed with error code:" << syncNum;
             //同步失败
             removeSyncToast();
             DMessageManager::instance()->sendMessage(this->window(), QIcon::fromTheme(":/icons/deepin/builtin/icons/dde_calendar_fail_200px.png"), tr("Sync failed, please try later"));
@@ -966,6 +990,7 @@ void Calendarmainwindow::slotShowSyncToast(int syncNum)
 
 void Calendarmainwindow::slotAccountUpdate()
 {
+    qCDebug(ClientLogger) << "Updating account information";
     AccountItem::Ptr uidAccount = gUosAccountItem;
     if (!uidAccount.isNull()) {
         connect(uidAccount.get(), &AccountItem::signalSyncStateChange, this, &Calendarmainwindow::slotShowSyncToast);
