@@ -3,700 +3,696 @@
     <name>AccountItem</name>
     <message>
         <source>Sync successful</source>
-        <translation type="unfinished"/>
+        <translation>التناسق ناجح</translation>
     </message>
     <message>
         <source>Network error</source>
-        <translation type="unfinished"/>
+        <translation>خطأ في الشبكة</translation>
     </message>
     <message>
         <source>Server exception</source>
-        <translation type="unfinished"/>
+        <translation>استثناء في الخادم</translation>
     </message>
     <message>
         <source>Storage full</source>
-        <translation type="unfinished"/>
+        <translation>التخزين ممتلئ</translation>
     </message>
 </context>
 <context>
     <name>AccountManager</name>
     <message>
         <source>Local account</source>
-        <translation type="unfinished"/>
+        <translation>الحساب المحلي</translation>
     </message>
     <message>
         <source>Event types</source>
-        <translation type="unfinished"/>
+        <translation>أنواع الأحداث</translation>
     </message>
 </context>
 <context>
     <name>CColorPickerWidget</name>
     <message>
         <source>Color</source>
-        <translation type="unfinished"/>
+        <translation>اللون</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation>Sefsex</translation>
+        <translation type="vanished">Sefsex</translation>
     </message>
     <message>
         <source>Save</source>
         <comment>button</comment>
-        <translation>Sekles</translation>
+        <translation type="vanished">Sekles</translation>
     </message>
 </context>
 <context>
     <name>CDayMonthView</name>
     <message>
         <source>Monday</source>
-        <translation>Arim</translation>
+        <translation type="vanished">Arim</translation>
     </message>
     <message>
         <source>Tuesday</source>
-        <translation>Aram</translation>
+        <translation type="vanished">Aram</translation>
     </message>
     <message>
         <source>Wednesday</source>
-        <translation>Ahad</translation>
+        <translation type="vanished">Ahad</translation>
     </message>
     <message>
         <source>Thursday</source>
-        <translation>Amhad</translation>
+        <translation type="vanished">Amhad</translation>
     </message>
     <message>
         <source>Friday</source>
-        <translation>Sem</translation>
+        <translation type="vanished">Sem</translation>
     </message>
     <message>
         <source>Saturday</source>
-        <translation>Sed</translation>
+        <translation type="vanished">Sed</translation>
     </message>
     <message>
         <source>Sunday</source>
-        <translation>Acer</translation>
+        <translation type="vanished">Acer</translation>
     </message>
 </context>
 <context>
     <name>CDayWindow</name>
     <message>
         <source>Y</source>
-        <translation>Aseggas</translation>
+        <translation type="vanished">Aseggas</translation>
     </message>
     <message>
         <source>M</source>
-        <translation>Ayyur</translation>
+        <translation type="vanished">Ayyur</translation>
     </message>
     <message>
         <source>D</source>
-        <translation>Ass</translation>
+        <translation type="vanished">Ass</translation>
     </message>
     <message>
         <source>Lunar</source>
-        <translation type="unfinished"/>
+        <translation>القمر</translation>
     </message>
 </context>
 <context>
     <name>CGraphicsView</name>
     <message>
         <source>New Event</source>
-        <translation>Tadyant tamaynut</translation>
+        <translation type="vanished">Tadyant tamaynut</translation>
     </message>
 </context>
 <context>
     <name>CMonthScheduleNumItem</name>
     <message>
         <source>%1 more</source>
-        <translation>Ugar n 1%</translation>
+        <translation type="vanished">Ugar n 1%</translation>
     </message>
 </context>
 <context>
     <name>CMonthView</name>
     <message>
         <source>New event</source>
-        <translation>Tadyant tamaynut</translation>
+        <translation type="vanished">Tadyant tamaynut</translation>
     </message>
     <message>
         <source>New Event</source>
-        <translation>Tadyant tamaynut</translation>
+        <translation type="vanished">Tadyant tamaynut</translation>
     </message>
 </context>
 <context>
     <name>CMonthWindow</name>
     <message>
         <source>Y</source>
-        <translation>Aseggas</translation>
+        <translation type="vanished">Aseggas</translation>
     </message>
 </context>
 <context>
     <name>CMyScheduleView</name>
     <message>
         <source>My Event</source>
-        <translation>Tadyant-iw</translation>
+        <translation type="vanished">Tadyant-iw</translation>
     </message>
     <message>
         <source>OK</source>
         <comment>button</comment>
-        <translation>IH</translation>
+        <translation type="vanished">IH</translation>
     </message>
     <message>
         <source>Delete</source>
         <comment>button</comment>
-        <translation>Kkes</translation>
+        <translation type="vanished">Kkes</translation>
     </message>
     <message>
         <source>Edit</source>
         <comment>button</comment>
-        <translation>Ẓreg</translation>
+        <translation type="vanished">Ẓreg</translation>
     </message>
 </context>
 <context>
     <name>CPushButton</name>
     <message>
         <source>New event type</source>
-        <translation type="unfinished"/>
+        <translation>نوع حدث جديد</translation>
     </message>
 </context>
 <context>
     <name>CScheduleDlg</name>
     <message>
         <source>New Event</source>
-        <translation>Tadyant tamaynut</translation>
+        <translation type="vanished">Tadyant tamaynut</translation>
     </message>
     <message>
         <source>Edit Event</source>
-        <translation>Ẓreg tadyant</translation>
+        <translation type="vanished">Ẓreg tadyant</translation>
     </message>
     <message>
         <source>End time must be greater than start time</source>
-        <translation>Akud n taggara yezmer d netta ara igerrzen ɣef wakud n tazwara</translation>
+        <translation type="vanished">Akud n taggara yezmer d netta ara igerrzen ɣef wakud n tazwara</translation>
     </message>
     <message>
         <source>OK</source>
         <comment>button</comment>
-        <translation>IH</translation>
+        <translation type="vanished">IH</translation>
     </message>
     <message>
         <source>Never</source>
-        <translation>Werǧin</translation>
+        <translation type="vanished">Werǧin</translation>
     </message>
     <message>
         <source>At time of event</source>
-        <translation>Deg wakud n tedyant</translation>
+        <translation type="vanished">Deg wakud n tedyant</translation>
     </message>
     <message>
         <source>15 minutes before</source>
-        <translation>15 tesdatin send</translation>
+        <translation type="vanished">15 tesdatin send</translation>
     </message>
     <message>
         <source>30 minutes before</source>
-        <translation>30 tesdatin send</translation>
+        <translation type="vanished">30 tesdatin send</translation>
     </message>
     <message>
         <source>1 hour before</source>
-        <translation>1 usrag send</translation>
+        <translation type="vanished">1 usrag send</translation>
     </message>
     <message>
         <source>1 day before</source>
-        <translation>1 wass send</translation>
+        <translation type="vanished">1 wass send</translation>
     </message>
     <message>
         <source>2 days before</source>
-        <translation>2 wussan send</translation>
+        <translation type="vanished">2 wussan send</translation>
     </message>
     <message>
         <source>1 week before</source>
-        <translation>1 dduṛt send</translation>
+        <translation type="vanished">1 dduṛt send</translation>
     </message>
     <message>
         <source>On start day (9:00 AM)</source>
-        <translation>Deg tazwara n wass (9:00 SRG)</translation>
+        <translation type="vanished">Deg tazwara n wass (9:00 SRG)</translation>
     </message>
     <message>
         <source>time(s)</source>
-        <translation>Akud (akuden)</translation>
+        <translation type="vanished">Akud (akuden)</translation>
     </message>
     <message>
         <source>Enter a name please</source>
-        <translation type="unfinished"/>
+        <translation>الرجاء إدخال اسم</translation>
     </message>
     <message>
         <source>The name can not only contain whitespaces</source>
-        <translation type="unfinished"/>
+        <translation>الاسم لا يمكن أن يحتوي فقط على المسافات البيضاء</translation>
     </message>
     <message>
         <source>Type:</source>
-        <translation>Anaw:</translation>
+        <translation type="vanished">Anaw:</translation>
     </message>
     <message>
         <source>Description:</source>
-        <translation>Aglam:</translation>
+        <translation type="vanished">Aglam:</translation>
     </message>
     <message>
         <source>All Day:</source>
-        <translation>Yal ass:</translation>
+        <translation type="vanished">Yal ass:</translation>
     </message>
     <message>
         <source>Starts:</source>
-        <translation>Yebda</translation>
+        <translation type="vanished">Yebda</translation>
     </message>
     <message>
         <source>Ends:</source>
-        <translation>Yekfa</translation>
+        <translation type="vanished">Yekfa</translation>
     </message>
     <message>
         <source>Remind Me:</source>
-        <translation>Smekti-yi-d:</translation>
+        <translation type="vanished">Smekti-yi-d:</translation>
     </message>
     <message>
         <source>Repeat:</source>
-        <translation>Ales</translation>
+        <translation type="vanished">Ales</translation>
     </message>
     <message>
         <source>End Repeat:</source>
-        <translation>Taggara n wallus:</translation>
+        <translation type="vanished">Taggara n wallus:</translation>
     </message>
     <message>
         <source>Calendar account:</source>
-        <translation type="unfinished"/>
+        <translation>حساب الجدول:</translation>
     </message>
     <message>
         <source>Calendar account</source>
-        <translation type="unfinished"/>
+        <translation>حساب الجدول</translation>
     </message>
     <message>
         <source>Type</source>
-        <translation>Anaw</translation>
+        <translation type="vanished">Anaw</translation>
     </message>
     <message>
         <source>Description</source>
-        <translation>Aglam</translation>
+        <translation type="vanished">Aglam</translation>
     </message>
     <message>
         <source>All Day</source>
-        <translation>Meṛṛa ass</translation>
+        <translation type="vanished">Meṛṛa ass</translation>
     </message>
     <message>
         <source>Time:</source>
-        <translation type="unfinished"/>
+        <translation>الوقت:</translation>
     </message>
     <message>
         <source>Time</source>
-        <translation type="unfinished"/>
+        <translation>الوقت</translation>
     </message>
     <message>
         <source>Solar</source>
-        <translation type="unfinished"/>
+        <translation>الشمس</translation>
     </message>
     <message>
         <source>Lunar</source>
-        <translation type="unfinished"/>
+        <translation>القمر</translation>
     </message>
     <message>
         <source>Starts</source>
-        <translation>Yebda</translation>
+        <translation type="vanished">Yebda</translation>
     </message>
     <message>
         <source>Ends</source>
-        <translation>Yekfa</translation>
+        <translation type="vanished">Yekfa</translation>
     </message>
     <message>
         <source>Remind Me</source>
-        <translation>Smekti-yi-d</translation>
+        <translation type="vanished">Smekti-yi-d</translation>
     </message>
     <message>
         <source>Repeat</source>
-        <translation>Ales</translation>
+        <translation type="vanished">Ales</translation>
     </message>
     <message>
         <source>Daily</source>
-        <translation>S wass</translation>
+        <translation type="vanished">S wass</translation>
     </message>
     <message>
         <source>Weekdays</source>
-        <translation>Ussan n yimalas</translation>
+        <translation type="vanished">Ussan n yimalas</translation>
     </message>
     <message>
         <source>Weekly</source>
-        <translation>S yimalas</translation>
+        <translation type="vanished">S yimalas</translation>
     </message>
     <message>
         <source>Monthly</source>
-        <translation>S wayyur</translation>
+        <translation type="vanished">S wayyur</translation>
     </message>
     <message>
         <source>Yearly</source>
-        <translation>S useggas</translation>
+        <translation type="vanished">S useggas</translation>
     </message>
     <message>
         <source>End Repeat</source>
-        <translation>Taggara n wallus</translation>
+        <translation type="vanished">Taggara n wallus</translation>
     </message>
     <message>
         <source>After</source>
-        <translation>Seld</translation>
+        <translation type="vanished">Seld</translation>
     </message>
     <message>
         <source>On</source>
-        <translation>Ɣef</translation>
+        <translation type="vanished">Ɣef</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation>Sefsex</translation>
+        <translation type="vanished">Sefsex</translation>
     </message>
     <message>
         <source>Save</source>
         <comment>button</comment>
-        <translation>Sekles</translation>
+        <translation type="vanished">Sekles</translation>
     </message>
 </context>
 <context>
     <name>CScheduleOperation</name>
     <message>
         <source>All occurrences of a repeating event must have the same all-day status.</source>
-        <translation>Meṛṛa timeḍriwin n tedyant i d-yettuɣalen ilaq ad sɛunt yiwen waddad i wass kamel.</translation>
+        <translation type="vanished">Meṛṛa timeḍriwin n tedyant i d-yettuɣalen ilaq ad sɛunt yiwen waddad i wass kamel.</translation>
     </message>
     <message>
         <source>Do you want to change all occurrences?</source>
-        <translation>Tebɣiḍ ad tesnefleḍ meṛṛa timeḍriwin?</translation>
+        <translation type="vanished">Tebɣiḍ ad tesnefleḍ meṛṛa timeḍriwin?</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation>Sefsex</translation>
+        <translation type="vanished">Sefsex</translation>
     </message>
     <message>
         <source>Change All</source>
-        <translation>Senfel kullec</translation>
+        <translation type="vanished">Senfel kullec</translation>
     </message>
     <message>
         <source>You are changing the repeating rule of this event.</source>
-        <translation>Tbeddleḍ alugen i d-yettuɣalen n tedyant-a.</translation>
+        <translation type="vanished">Tbeddleḍ alugen i d-yettuɣalen n tedyant-a.</translation>
     </message>
     <message>
         <source>You are deleting an event.</source>
-        <translation>Tekkseḍ yiwet tedyant.</translation>
+        <translation type="vanished">Tekkseḍ yiwet tedyant.</translation>
     </message>
     <message>
         <source>Are you sure you want to delete this event?</source>
-        <translation>D tidet tebɣiḍ ad tekkseḍ tadyant-a?</translation>
+        <translation type="vanished">D tidet tebɣiḍ ad tekkseḍ tadyant-a?</translation>
     </message>
     <message>
         <source>Delete</source>
         <comment>button</comment>
-        <translation>Kkes</translation>
+        <translation type="vanished">Kkes</translation>
     </message>
     <message>
         <source>Do you want to delete all occurrences of this event, or only the selected occurrence?</source>
-        <translation>Tebɣiḍ ad tekkseḍ meṛṛa timeḍriwin n tedyant-a neɣ tid kan i d-yettwafernen?</translation>
+        <translation type="vanished">Tebɣiḍ ad tekkseḍ meṛṛa timeḍriwin n tedyant-a neɣ tid kan i d-yettwafernen?</translation>
     </message>
     <message>
         <source>Delete All</source>
-        <translation>Kkes kullec</translation>
+        <translation type="vanished">Kkes kullec</translation>
     </message>
     <message>
         <source>Delete Only This Event</source>
-        <translation>Kkes kan tadyant-a</translation>
+        <translation type="vanished">Kkes kan tadyant-a</translation>
     </message>
     <message>
         <source>Do you want to delete this and all future occurrences of this event, or only the selected occurrence?</source>
-        <translation>Tebɣiḍ ad tekkseḍ timeḍriwt-a d tid meṛṛa i d-iteddun, neɣ d tid kan i d-yettufernen?</translation>
+        <translation type="vanished">Tebɣiḍ ad tekkseḍ timeḍriwt-a d tid meṛṛa i d-iteddun, neɣ d tid kan i d-yettufernen?</translation>
     </message>
     <message>
         <source>Delete All Future Events</source>
-        <translation>Kkes meṛṛa tidyanin i d-iteddun</translation>
+        <translation type="vanished">Kkes meṛṛa tidyanin i d-iteddun</translation>
     </message>
     <message>
         <source>You are changing a repeating event.</source>
-        <translation>Tbeddleḍ tadyant i d-yettuɣalen.</translation>
+        <translation type="vanished">Tbeddleḍ tadyant i d-yettuɣalen.</translation>
     </message>
     <message>
         <source>Do you want to change only this occurrence of the event, or all occurrences?</source>
-        <translation>Tebɣiḍ ad tbeddleḍ timeḍriwt-agi kan  n tedyant, neɣ meṛṛa timeḍriwen?</translation>
+        <translation type="vanished">Tebɣiḍ ad tbeddleḍ timeḍriwt-agi kan  n tedyant, neɣ meṛṛa timeḍriwen?</translation>
     </message>
     <message>
         <source>All</source>
-        <translation>Meṛṛa</translation>
+        <translation type="vanished">Meṛṛa</translation>
     </message>
     <message>
         <source>Only This Event</source>
-        <translation>Tadyant-agi kan</translation>
+        <translation type="vanished">Tadyant-agi kan</translation>
     </message>
     <message>
         <source>Do you want to change only this occurrence of the event, or this and all future occurrences?</source>
-        <translation>Tebɣiḍ ad tbeddleḍ timeḍriwt-a n tedyant, neɣ tagi d meṛṛa timeḍriwen i d-iteddun?</translation>
+        <translation type="vanished">Tebɣiḍ ad tbeddleḍ timeḍriwt-a n tedyant, neɣ tagi d meṛṛa timeḍriwen i d-iteddun?</translation>
     </message>
     <message>
         <source>All Future Events</source>
-        <translation>Tidyanin akk i d-iteddun</translation>
+        <translation type="vanished">Tidyanin akk i d-iteddun</translation>
     </message>
     <message>
         <source>You have selected a leap month, and will be reminded according to the rules of the lunar calendar.</source>
-        <translation type="unfinished"/>
+        <translation>لقد اخترت شهرًا زائدًا، ولسوف تُذكَّر وفقًا للقواعد الخاصة بالGregorian calendar.</translation>
     </message>
     <message>
         <source>OK</source>
         <comment>button</comment>
-        <translation>IH</translation>
+        <translation type="vanished">IH</translation>
     </message>
 </context>
 <context>
     <name>CScheduleSearchDateItem</name>
     <message>
         <source>Y</source>
-        <translation>Aseggas</translation>
+        <translation type="vanished">Aseggas</translation>
     </message>
     <message>
         <source>M</source>
-        <translation>Ayyur</translation>
+        <translation type="vanished">Ayyur</translation>
     </message>
     <message>
         <source>D</source>
-        <translation>Ass</translation>
+        <translation type="vanished">Ass</translation>
     </message>
 </context>
 <context>
     <name>CScheduleSearchItem</name>
     <message>
         <source>Edit</source>
-        <translation>Ẓreg</translation>
+        <translation type="vanished">Ẓreg</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation>Kkes</translation>
+        <translation type="vanished">Kkes</translation>
     </message>
     <message>
         <source>All Day</source>
-        <translation>Meṛṛa ass</translation>
+        <translation type="vanished">Meṛṛa ass</translation>
     </message>
 </context>
 <context>
     <name>CScheduleSearchView</name>
     <message>
         <source>No search results</source>
-        <translation>Ulac igmaḍ n unadi</translation>
+        <translation type="vanished">Ulac igmaḍ n unadi</translation>
     </message>
 </context>
 <context>
     <name>CScheduleView</name>
     <message>
         <source>ALL DAY</source>
-        <translation>YAL ASS</translation>
+        <translation type="vanished">YAL ASS</translation>
     </message>
 </context>
 <context>
     <name>CSettingDialog</name>
-    <message>
-        <source>import ICS file</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>Manual</source>
-        <translation>S ufus</translation>
+        <translation type="vanished">S ufus</translation>
     </message>
     <message>
         <source>15 mins</source>
-        <translation type="unfinished"/>
+        <translation>15 دقيقة</translation>
     </message>
     <message>
         <source>30 mins</source>
-        <translation type="unfinished"/>
+        <translation>30 دقيقة</translation>
     </message>
     <message>
         <source>1 hour</source>
-        <translation type="unfinished"/>
+        <translation>ساعة واحدة</translation>
     </message>
     <message>
         <source>24 hours</source>
-        <translation type="unfinished"/>
+        <translation>24 ساعة</translation>
     </message>
     <message>
         <source>Sync Now</source>
-        <translation type="unfinished"/>
+        <translation>التناسق الآن</translation>
     </message>
     <message>
         <source>Last sync</source>
-        <translation type="unfinished"/>
+        <translation>التناسق السابق</translation>
     </message>
     <message>
         <source>Monday</source>
-        <translation>Arim</translation>
-    </message>
-    <message>
-        <source>Tuesday</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Wednesday</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Thursday</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Friday</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Saturday</source>
-        <translation type="unfinished"/>
+        <translation type="vanished">Arim</translation>
     </message>
     <message>
         <source>Sunday</source>
-        <translation>Acer</translation>
+        <translation type="vanished">Acer</translation>
     </message>
     <message>
         <source>12-hour clock</source>
-        <translation type="unfinished"/>
+        <translation>الساعة بتنسيق 12 ساعة</translation>
     </message>
     <message>
         <source>24-hour clock</source>
-        <translation type="unfinished"/>
+        <translation>الساعة بتنسيق 24 ساعة</translation>
+    </message>
+    <message>
+        <source>Tuesday</source>
+        <translation>يوم الثلاثاء</translation>
+    </message>
+    <message>
+        <source>Wednesday</source>
+        <translation>يوم الأربعاء</translation>
+    </message>
+    <message>
+        <source>Thursday</source>
+        <translation>يوم الخميس</translation>
+    </message>
+    <message>
+        <source>Friday</source>
+        <translation>يوم الجمعة</translation>
+    </message>
+    <message>
+        <source>Saturday</source>
+        <translation>الأربعاء</translation>
     </message>
 </context>
 <context>
     <name>CTimeEdit</name>
     <message>
         <source>(%1 mins)</source>
-        <translation type="unfinished"/>
+        <translation>(%1 دقائق)</translation>
     </message>
     <message>
         <source>(%1 hour)</source>
-        <translation type="unfinished"/>
+        <translation>(%1 ساعة)</translation>
     </message>
     <message>
         <source>(%1 hours)</source>
-        <translation type="unfinished"/>
+        <translation>(%1 ساعات)</translation>
     </message>
 </context>
 <context>
     <name>CTitleWidget</name>
     <message>
         <source>Y</source>
-        <translation>Aseggas</translation>
+        <translation type="vanished">Aseggas</translation>
     </message>
     <message>
         <source>M</source>
-        <translation>Ayyur</translation>
+        <translation type="vanished">Ayyur</translation>
     </message>
     <message>
         <source>W</source>
-        <translation>Imalas</translation>
+        <translation type="vanished">Imalas</translation>
     </message>
     <message>
         <source>D</source>
-        <translation>Ass</translation>
+        <translation type="vanished">Ass</translation>
     </message>
     <message>
         <source>Search events and festivals</source>
-        <translation type="unfinished"/>
+        <translation>ابحث عن الأحداث والمعارض</translation>
     </message>
 </context>
 <context>
     <name>CWeekWidget</name>
     <message>
         <source>Sun</source>
-        <translation type="unfinished"/>
+        <translation>الأحد</translation>
     </message>
     <message>
         <source>Mon</source>
-        <translation type="unfinished"/>
+        <translation>الاثنين</translation>
     </message>
     <message>
         <source>Tue</source>
-        <translation type="unfinished"/>
+        <translation>الثلاثاء</translation>
     </message>
     <message>
         <source>Wed</source>
-        <translation type="unfinished"/>
+        <translation>الأربعاء</translation>
     </message>
     <message>
         <source>Thu</source>
-        <translation type="unfinished"/>
+        <translation>الخميس</translation>
     </message>
     <message>
         <source>Fri</source>
-        <translation type="unfinished"/>
+        <translation>الجمعة</translation>
     </message>
     <message>
         <source>Sat</source>
-        <translation type="unfinished"/>
+        <translation>السبت</translation>
     </message>
 </context>
 <context>
     <name>CWeekWindow</name>
     <message>
         <source>Week</source>
-        <translation>Dduṛt</translation>
+        <translation type="vanished">Dduṛt</translation>
     </message>
     <message>
         <source>Y</source>
-        <translation>Aseggas</translation>
+        <translation type="vanished">Aseggas</translation>
     </message>
 </context>
 <context>
     <name>CYearScheduleView</name>
     <message>
         <source>All Day</source>
-        <translation>Meṛṛa ass</translation>
+        <translation type="vanished">Meṛṛa ass</translation>
     </message>
     <message>
         <source>No event</source>
-        <translation>Ulac tadyant</translation>
+        <translation type="vanished">Ulac tadyant</translation>
     </message>
 </context>
 <context>
     <name>CYearWindow</name>
     <message>
         <source>Y</source>
-        <translation>Aseggas</translation>
+        <translation type="vanished">Aseggas</translation>
     </message>
 </context>
 <context>
     <name>CalendarWindow</name>
     <message>
         <source>Calendar</source>
-        <translation>Awitay</translation>
+        <translation type="vanished">Awitay</translation>
     </message>
     <message>
         <source>Calendar is a tool to view dates, and also a smart daily planner to schedule all things in life. </source>
-        <translation>Awitay d afecku i uskan n wazemz akked daɣen d aɣawas n yal ass i usɣiwes n wayen akk ara tgeḍ deg tudert.</translation>
+        <translation type="vanished">Awitay d afecku i uskan n wazemz akked daɣen d aɣawas n yal ass i usɣiwes n wayen akk ara tgeḍ deg tudert.</translation>
     </message>
 </context>
 <context>
     <name>Calendarmainwindow</name>
     <message>
         <source>Calendar</source>
-        <translation>Awitay</translation>
+        <translation type="vanished">Awitay</translation>
     </message>
     <message>
         <source>Manage</source>
-        <translation type="unfinished"/>
+        <translation>الإدارة</translation>
     </message>
     <message>
         <source>Privacy Policy</source>
-        <translation>Tasertit n tbaḍnit</translation>
+        <translation type="vanished">Tasertit n tbaḍnit</translation>
     </message>
     <message>
         <source>Syncing...</source>
-        <translation>Amtawi...</translation>
+        <translation type="vanished">Amtawi...</translation>
     </message>
     <message>
         <source>Sync successful</source>
-        <translation type="unfinished"/>
+        <translation>تم التزامن بنجاح</translation>
     </message>
     <message>
         <source>Sync failed, please try later</source>
-        <translation type="unfinished"/>
+        <translation>فشل التزامن، يرجى المحاولة لاحقًا</translation>
     </message>
 </context>
 <context>
     <name>CenterWidget</name>
     <message>
         <source>All Day</source>
-        <translation>Yal ass</translation>
+        <translation type="vanished">Yal ass</translation>
     </message>
 </context>
 <context>
@@ -735,15 +731,15 @@
     </message>
     <message>
         <source>15 mins later</source>
-        <translation type="unfinished"/>
+        <translation>بعد 15 دقيقة</translation>
     </message>
     <message>
         <source>1 hour later</source>
-        <translation type="unfinished"/>
+        <translation>بعد ساعة</translation>
     </message>
     <message>
         <source>4 hours later</source>
-        <translation type="unfinished"/>
+        <translation>بعد 4 ساعات</translation>
     </message>
     <message>
         <source>Tomorrow</source>
@@ -766,99 +762,91 @@
     <name>DragInfoGraphicsView</name>
     <message>
         <source>Edit</source>
-        <translation>Ẓreg</translation>
+        <translation type="vanished">Ẓreg</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation>Kkes</translation>
+        <translation type="vanished">Kkes</translation>
     </message>
     <message>
         <source>New event</source>
-        <translation>Tadyant tamaynut</translation>
+        <translation type="vanished">Tadyant tamaynut</translation>
     </message>
     <message>
         <source>New Event</source>
-        <translation>Tadyant tamaynut</translation>
+        <translation type="vanished">Tadyant tamaynut</translation>
     </message>
 </context>
 <context>
     <name>JobTypeListView</name>
-    <message>
-        <source>export</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>import ICS file</source>
-        <translation type="unfinished"/>
-    </message>
     <message>
         <source>You are deleting an event type.</source>
-        <translation type="unfinished"/>
+        <translation>أنت تقوم بحذف نوع حدث.</translation>
     </message>
     <message>
         <source>All events under this type will be deleted and cannot be recovered.</source>
-        <translation type="unfinished"/>
+        <translation>سيتم حذف جميع الأحداث المرتبطة بهذا النوع ولا يمكن استعادتها.</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation>Sefsex</translation>
+        <translation type="vanished">Sefsex</translation>
     </message>
     <message>
         <source>Delete</source>
         <comment>button</comment>
-        <translation>Kkes</translation>
+        <translation type="vanished">Kkes</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
         <source>Account settings</source>
-        <translation type="unfinished"/>
+        <translation>إعدادات الحساب</translation>
     </message>
     <message>
         <source>Account</source>
-        <translation type="unfinished"/>
+        <translation>الحساب</translation>
     </message>
     <message>
         <source>Select items to be synced</source>
-        <translation type="unfinished"/>
+        <translation>اختر العناصر التي سيتم تزامنها</translation>
     </message>
     <message>
         <source>Events</source>
-        <translation type="unfinished"/>
+        <translation>الأحداث</translation>
     </message>
     <message>
         <source>General settings</source>
-        <translation type="unfinished"/>
+        <translation>الإعدادات العامة</translation>
     </message>
     <message>
         <source>Sync interval</source>
-        <translation type="unfinished"/>
+        <translation>فترة التزامن</translation>
     </message>
     <message>
         <source>Manage calendar</source>
-        <translation type="unfinished"/>
+        <translation>إدارة التقويم</translation>
     </message>
     <message>
         <source>Calendar account</source>
-        <translation type="unfinished"/>
+        <translation>حساب التقويم</translation>
     </message>
     <message>
         <source>Event types</source>
-        <translation type="unfinished"/>
+        <translation>أنواع الأحداث</translation>
     </message>
     <message>
         <source>General</source>
-        <translation>Amatu</translation>
+        <translation type="vanished">Amatu</translation>
     </message>
     <message>
         <source>First day of week</source>
-        <translation type="unfinished"/>
+        <translation>أول يوم من الأسبوع</translation>
     </message>
     <message>
         <source>Time</source>
-        <translation type="unfinished"/>
+        <translation>أوقات</translation>
     </message>
 </context>
 <context>
@@ -866,7 +854,7 @@
     <message>
         <source>Today</source>
         <comment>Return</comment>
-        <translation>Ass-a</translation>
+        <translation type="vanished">Ass-a</translation>
     </message>
 </context>
 <context>
@@ -874,94 +862,86 @@
     <message>
         <source>Today</source>
         <comment>Return Today</comment>
-        <translation>Ass-a</translation>
+        <translation type="vanished">Ass-a</translation>
     </message>
 </context>
 <context>
     <name>ScheduleTypeEditDlg</name>
     <message>
         <source>New event type</source>
-        <translation type="unfinished"/>
+        <translation>نوع حدث جديد</translation>
     </message>
     <message>
         <source>Edit event type</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>Import ICS file</source>
-        <translation type="unfinished"/>
+        <translation>تحرير نوع الحدث</translation>
     </message>
     <message>
         <source>Name:</source>
-        <translation>Isem:</translation>
+        <translation type="vanished">Isem:</translation>
     </message>
     <message>
         <source>Color:</source>
-        <translation type="unfinished"/>
-    </message>
-    <message>
-        <source>&lt;a href=&apos;https://wikipedia.org/wiki/ICalendar&apos;&gt;ICS&lt;/a&gt; File:</source>
-        <translation type="unfinished"/>
+        <translation>اللون:</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation>Sefsex</translation>
+        <translation type="vanished">Sefsex</translation>
     </message>
     <message>
         <source>Save</source>
         <comment>button</comment>
-        <translation>Sekles</translation>
+        <translation type="vanished">Sekles</translation>
     </message>
     <message>
         <source>The name can not only contain whitespaces</source>
-        <translation type="unfinished"/>
+        <translation>الاسم لا يمكن أن يحتوي فقط على مسافات بيضاء</translation>
     </message>
     <message>
         <source>Enter a name please</source>
-        <translation type="unfinished"/>
+        <translation>الرجاء إدخال اسم</translation>
     </message>
 </context>
 <context>
     <name>Shortcut</name>
     <message>
         <source>Help</source>
-        <translation>Tallalt</translation>
+        <translation type="vanished">Tallalt</translation>
     </message>
     <message>
         <source>Delete event</source>
-        <translation>Kkes tadyant</translation>
+        <translation type="vanished">Kkes tadyant</translation>
     </message>
     <message>
         <source>Copy</source>
-        <translation>Nɣel</translation>
+        <translation type="vanished">Nɣel</translation>
     </message>
     <message>
         <source>Cut</source>
-        <translation>Gzem</translation>
+        <translation type="vanished">Gzem</translation>
     </message>
     <message>
         <source>Paste</source>
-        <translation>Senteḍ</translation>
+        <translation type="vanished">Senteḍ</translation>
     </message>
     <message>
         <source>Delete</source>
-        <translation>Kkes</translation>
+        <translation type="vanished">Kkes</translation>
     </message>
     <message>
         <source>Select all</source>
-        <translation>Fren kullec</translation>
+        <translation type="vanished">Fren kullec</translation>
     </message>
 </context>
 <context>
     <name>SidebarCalendarWidget</name>
     <message>
         <source>Y</source>
-        <translation>Aseggas</translation>
+        <translation type="vanished">Aseggas</translation>
     </message>
     <message>
         <source>M</source>
-        <translation>Ayyur</translation>
+        <translation type="vanished">Ayyur</translation>
     </message>
 </context>
 <context>
@@ -969,7 +949,7 @@
     <message>
         <source>Go</source>
         <comment>button</comment>
-        <translation type="unfinished"/>
+        <translation>اذهب</translation>
     </message>
 </context>
 <context>
@@ -977,19 +957,19 @@
     <message>
         <source>Sign In</source>
         <comment>button</comment>
-        <translation>Kcem</translation>
+        <translation type="vanished">Kcem</translation>
     </message>
     <message>
         <source>Sign Out</source>
         <comment>button</comment>
-        <translation>Ffeɣ</translation>
+        <translation type="vanished">Ffeɣ</translation>
     </message>
 </context>
 <context>
     <name>YearFrame</name>
     <message>
         <source>Y</source>
-        <translation>Aseggas</translation>
+        <translation type="vanished">Aseggas</translation>
     </message>
 </context>
 <context>
@@ -997,7 +977,7 @@
     <message>
         <source>Today</source>
         <comment>Today</comment>
-        <translation>Ass-a</translation>
+        <translation type="vanished">Ass-a</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
